--
-- MultiDischargeParticleSystems
-- Specialization for more than one discharge particle system
--
-- @author  Stefan Maurus	
-- @date  12/04/14

-- Copyright © Stefan Maurus, www.stefanmaurus.de

--[[
    <multiDischargeParticleSystems> <!--Level 3 = y-Scale of ref over 0.75 //Level 2 = y-Scale of ref over 0.33 up to 0.66 //Level 1 = y-Scale of ref under 0.33 | INDEX has to be scaled as plane-->
		<multiDischargeParticleSystem type="FRUITTYPE" level="LEVEL" index="INDEX" file="PATH"/>			
    </multiDischargeParticleSystems>	
]]

MultiDischargeParticleSystems = {};

function MultiDischargeParticleSystems.prerequisitesPresent(specializations)
    return true;
end;

function MultiDischargeParticleSystems:load(xmlFile)
	self.scaleReference = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.multiDischargeParticleSystems#reference"));
	self.cutScale = getXMLFloat(xmlFile, "vehicle.multiDischargeParticleSystems#cut");

	local i = 0;
	self.multiDischargeParticleSystems = {};
	while true do
        local key = string.format("vehicle.multiDischargeParticleSystems.multiDischargeParticleSystem(%d)", i);
		if not hasXMLProperty(xmlFile, key) then
			break;
		end;
		local index = Utils.indexToObject(self.components, getXMLString(xmlFile, key.."#index"));
		
		local fruitType = Fillable.fillTypeNameToInt[getXMLString(xmlFile, key.."#type")]
		local level = getXMLFloat(xmlFile, key.."#level");

		local particleSystem = {};
        Utils.loadParticleSystem(xmlFile, particleSystem, key, index, false, nil, self.baseDirectory)	
		
		table.insert(self.multiDischargeParticleSystems, {fruitType=fruitType, level=level, particleSystem=particleSystem});
		i = i + 1;
	end;
end;

function MultiDischargeParticleSystems:delete()
	for _, ps in pairs(self.multiDischargeParticleSystems) do
		Utils.deleteParticleSystem(ps.particleSystem);
	end;	
end;

function MultiDischargeParticleSystems:readStream(streamId, connection)
end;

function MultiDischargeParticleSystems:writeStream(streamId, connection) 
end;

function MultiDischargeParticleSystems:mouseEvent(posX, posY, isDown, isUp, button)
end;

function MultiDischargeParticleSystems:keyEvent(unicode, sym, modifier, isDown)
end;

function MultiDischargeParticleSystems:update(dt)
	if self.tipState == 2 then
		local _,y,_ = getScale(self.scaleReference);
		for _, ps in pairs(self.multiDischargeParticleSystems) do
			if ps.fruitType == self.currentFillType then
				if ps.level == 1 then
					Utils.setEmittingState(ps.particleSystem, true);
				elseif y > self.cutScale and ps.level == 2 then
					Utils.setEmittingState(ps.particleSystem, true);
				else
					Utils.setEmittingState(ps.particleSystem, false);
				end;
			else  
				Utils.setEmittingState(ps.particleSystem, false);
			end;
		end;
	else
		for _, ps in pairs(self.multiDischargeParticleSystems) do
			Utils.setEmittingState(ps.particleSystem, false);
		end;
	end;
end;

function MultiDischargeParticleSystems:updateTick(dt)	
end;

function MultiDischargeParticleSystems:draw()
end;

function MultiDischargeParticleSystems:onAttach()
end;

function MultiDischargeParticleSystems:onDetach()	
end; 